@@ -1,20 +1,15 @@
 package Dancer2::Plugin::REST;
 our $AUTHORITY = 'cpan:SUKRIA';
 # ABSTRACT: A plugin for writing RESTful apps with Dancer2
-$Dancer2::Plugin::REST::VERSION = '0.26';
+$Dancer2::Plugin::REST::VERSION = '0.27';
 use strict;
 use warnings;
 
 use Carp 'croak';
 
-use Dancer2 0.149000_01;
 use Dancer2::Plugin;
 use Class::Load qw/ try_load_class /;
 
-use Moo::Role;
-
-with 'Dancer2::Plugin';
-
 # [todo] - add XML support
 my $content_types = {
     json => 'application/json',
@@ -195,7 +190,7 @@ Dancer2::Plugin::REST - A plugin for writing RESTful apps with Dancer2
 
 =head1 VERSION
 
-version 0.26
+version 0.27
 
 =head1 DESCRIPTION
 
